@@ -39,8 +39,10 @@ SPEC_REGIONS = {
     'cn-north-1': 'https://cfn-resource-specifications-cn-north-1-prod.s3.cn-north-1.amazonaws.com.cn/latest/gzip/CloudFormationResourceSpecification.json',
     'cn-northwest-1': 'https://cfn-resource-specifications-cn-northwest-1-prod.s3.cn-northwest-1.amazonaws.com.cn/latest/gzip/CloudFormationResourceSpecification.json',
     'eu-central-1': 'https://d1mta8qj7i28i2.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json',
+    'eu-central-2': 'https://cfn-resource-specifications-eu-central-2-prod.s3.eu-central-2.amazonaws.com/latest/gzip/CloudFormationResourceSpecification.json',
     'eu-north-1': 'https://diy8iv58sj6ba.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json',
     'eu-south-1': 'https://cfn-resource-specifications-eu-south-1-prod.s3.eu-south-1.amazonaws.com/latest/gzip/CloudFormationResourceSpecification.json',
+    'eu-south-2': 'https://cfn-resource-specifications-eu-south-2-prod.s3.eu-south-2.amazonaws.com/latest/gzip/CloudFormationResourceSpecification.json',
     'eu-west-1': 'https://d3teyb21fexa9r.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json',
     'eu-west-2': 'https://d1742qcu2c1ncx.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json',
     'eu-west-3': 'https://d2d0mfegowb3wk.cloudfront.net/latest/gzip/CloudFormationResourceSpecification.json',
@@ -343,6 +345,12 @@ def load_resource(package, filename='us-east-1.json'):
     :param filename: filename to load
     :return: Json output of the resource laoded
     """
+    if sys.version_info >= (3, 9):
+        return json.loads(
+            pkg_resources.files(package)  # pylint: disable=no-member
+            .joinpath(filename)
+            .read_text(encoding='utf-8')
+        )
     return json.loads(pkg_resources.read_text(package, filename, encoding='utf-8'))
 
 
@@ -435,8 +443,21 @@ def bool_compare(first, second):
 
 def initialize_specs():
     """Reload Resource Specs"""
-    for reg in REGIONS:
-        RESOURCE_SPECS[reg] = load_resource(CloudSpecs, filename=(f'{reg}.json'))
+
+    def load_region(region):
+        spec = load_resource(CloudSpecs, filename=(f'{region}.json'))
+
+        for section, section_values in spec.items():
+            if section in ['ResourceTypes', 'PropertyTypes', 'ValueTypes']:
+                for key, value in section_values.items():
+                    if value == 'CACHED':
+                        spec[section][key] = RESOURCE_SPECS['us-east-1'][section][key]
+        return spec
+
+    RESOURCE_SPECS['us-east-1'] = load_region('us-east-1')
+    for region in REGIONS:
+        if region != 'us-east-1':
+            RESOURCE_SPECS[region] = load_region(region)
 
 
 initialize_specs()
